# $Id: circle.tcl,v 1.1 1996/08/26 15:24:56 uwe Exp $
#
# routines for creating a canvas and for moving circles around

proc initCanvas {} {
    global state

    set c $state(canvas)

    canvas $c
    $c configure -height $state(height) -width $state(width)
    pack $c
}

proc moveCircle {who x y} {
    global state

    message 3 "moveCircle: $who at $x $y"

    if [info exists state($who,x)] {

	set dx [expr $x - $state($who,x)]
	set dy [expr $y - $state($who,y)]
	$state(canvas) move $who $dx $dy
    
	set state($who,x) $x
	set state($who,y) $y
    }

    return
}

proc createCircle {who color} {
    global state

    if {! [info exists state($who,x)]} {

	set x [expr $state(width)  / 2]
	set y [expr $state(height) / 2]

	set state($who,x) $x
	set state($who,y) $y

	set x0 [expr $x - $state(radius)]
	set y0 [expr $y - $state(radius)]
	set x1 [expr $x + $state(radius)]
	set y1 [expr $y + $state(radius)]

	$state(canvas) create oval $x0 $y0 $x1 $y1 -fill $color -width 0 -outline $color -tags $who

	if {"$who" != $state(whoami)} {
	    copyCircleConfig
	}
    }
}

proc copyCircleConfig {} {
    global state

    set i $state(whoami)
    writeSocket "createCircle	$i $state(fill)"
    writeSocket "moveCircle	$i $state($state(whoami),x) $state($state(whoami),y)"    
    writeSocket "configCircle	$i [getCircleConfig $i]"
}

proc getCircleConfig {i} {
    global state

    set res ""
    foreach l [$state(canvas) itemconfigure $i] {
	lappend res [lindex $l 0] [lindex $l 4]
    }
    return $res
}

proc configCircle {who args} {
    global state

    if {[info exists state($who,x)]} {
	eval $state(canvas) itemconfigure $who $args
    }
}

proc deleteCircle {who} {
    global state

    if [info exists state($who,x)] {
	$state(canvas) delete $who
	unset state($who,x) state($who,y)
    }
}


